/////////////////////////////////////////////////////////////////////
// copy the files inside this folder inside your gamestudio folder
// open damage.wmp, build it and run it using damage.wdl
/////////////////////////////////////////////////////////////////////

var video_mode = 7; // 800x600
var video_depth = 16; // 16 bit mode

//////////////////////////////////////////////////////////////////////

var player_speed;
var vertex_coords;

//////////////////////////////////////////////////////////////////////

define head_pos skill1;
define middle_pos skill2;
define leg_pos skill3;

var bullet_pos;

//////////////////////////////////////////////////////////////////////

sound bullet_wav = <bullet.wav>;

//////////////////////////////////////////////////////////////////////

bmap crosshair_pcx = <crosshair.pcx>;

//////////////////////////////////////////////////////////////////////

string damage_wmb = <damage.wmb>;
string bullet_mdl = <bullet.mdl>;

//////////////////////////////////////////////////////////////////////

function compute_shot_pos();
function player_moves();
function shoot_bullet();
function remove_bullet();

///////////////////////////////////////////////////////////////////////

text info_txt
{
	layer = 20;
	pos_x = 0;
	pos_y = 0;
	font = _a4font;
	string = "head vertex:\nmiddle vertex:\nleg vertex:\nhit coord:";

	flags = visible;
}

panel crosshair_pan
{
	bmap = crosshair_pcx;
	layer = 20;
	pos_x = 0;
	pos_y = 0;

	flags = transparent, refresh, d3d, visible;
}

panel coords_pan
{
	layer = 20;
	pos_x = 80;
	pos_y = 0;

	digits = 0, 0, 4, _a4font, 1, vertex_coords.x;
	digits = 0, 9, 4, _a4font, 1, vertex_coords.y;
	digits = 0, 18, 4, _a4font, 1, vertex_coords.z;
	digits = 0, 27, 4, _a4font, 1, bullet_pos.z;

	flags = refresh, d3d, visible;
}

///////////////////////////////////////////////////////////////////////

function main()
{
	on_d = null;
	level_load (damage_wmb);
}	

action player_moves
{
	player = me;
	camera.pan = player.pan; // set the initial camera angle
	my.invisible = on; // no need to see the player because we are in 1st person mode
	crosshair_pan.pos_x = (screen_size.x - bmap_width(crosshair_pcx)) / 2;
	crosshair_pan.pos_y = (screen_size.y - bmap_height(crosshair_pcx)) / 2;
	while (1)
	{
		vec_set (camera.pos, my.pos);
		camera.tilt += 20 * mouse_force.y * time;
		camera.pan -= 20 * mouse_force.x * time;
		my.pan = camera.pan;
		my.tilt = camera.tilt;
		player_speed.x = 15 * (key_w - key_s) * time; // move forward / backward
		player_speed.y = 10 * (key_a - key_d) * time; // strafe left / right
		vec_set (temp, my.x);
		temp.z -= 1000;
		trace_mode = ignore_me + use_box;
		player_speed.z = -trace (my.x, temp);					
		move_mode = ignore_you + ignore_passable;	
		ent_move(player_speed, nullvector);

		if (mouse_left == 1)
		{
			ent_create (bullet_mdl, player.pos, shoot_bullet);
			snd_play (bullet_wav, 50, 0);
			while (mouse_left == 1) {wait (1);}
		}
		wait (1);
	}
}

action enemy
{
	my.enable_impact = on;
	my.enable_shoot = on;
	my.enable_entity = on;
	my.event = compute_shot_pos;
	while (my.skill5 == 0)
	{
		ent_cycle ("idle", 0); // single frame, no need to place it inside this while loop but if 
					     // you plan to have a "stand" loop the code for it should be here		

		vec_for_vertex(temp, my, 222); // enemy's head vertex 
		my.head_pos = temp.z;
		vertex_coords.x = my.head_pos;
		vec_for_vertex(temp, my, 235); // enemy's belly vertex 
		my.middle_pos = temp.z;
		vertex_coords.y = my.middle_pos;
		vec_for_vertex(temp, my, 171); // enemy's leg vertex (one of the legs)
		my.leg_pos = temp.z;
		vertex_coords.z = my.leg_pos;
	
		wait (1);
	}
}

function compute_shot_pos()
{
	my.skill5 = 1; // I'm hit! stops the while loop in action enemy
	vec_set(bullet_pos, you.pos); // store bullet's coords before they get lost (before the bullet disappears)
	wait (1); // now we can wait for a frame
	my.event = null; // don't react to other bullets from now on
	if (abs(bullet_pos.z - my.head_pos) < abs(bullet_pos.z - my.middle_pos)) // we've got a head shot, no need to check the legs
	{
		my.skill5 = 0;
		while (my.skill10 < 80) // skip the last frame
		{
			ent_cycle("head", my.skill10);
			my.skill10 += 4 * time;
			wait (1);
		}
	}
	else // middle or leg shot
	{
		if (abs(bullet_pos.z - my.middle_pos) < abs(bullet_pos.z - my.leg_pos)) // middle shot
		{
			my.skill10 = 0;
			while (my.skill10 < 80) // skip the last frame
			{
				ent_cycle("middle", my.skill10);
				my.skill10 += 2 * time;
				wait (1);
			}
		}
		else // leg shot
		{
			my.skill10 = 0;
			while (my.skill10 < 80) // skip the last frame
			{
				ent_cycle("leg", my.skill10);
				my.skill10 += 4 * time;
				wait (1);
			}
		}
	}
}

function shoot_bullet()
{
	wait (1);
//	my.invisible = on; // remove the comment to hide the bullets
	my.enable_entity = on;
	my.enable_block = on;
	my.event = remove_bullet;
	my.passable = on;
	my.pan = player.pan;
	my.tilt = camera.tilt;

	my.light = on;
	my.lightrange = 0;
	my.lightblue = 250;
	my.bright = on;

	my.skill20 = 0;
	my.skill1 = 300;
	my.skill2 = 0;
	my.skill3 = 0;
	my.skill1 *= time;

	while (my.skill20 < 250)
	{
		if (my == null) {return;}
		if (my.skill20 < 1)  // don't collide with the player
		{
			my.passable = on;
		}
		else	
		{
			my.passable = off;
		}
		my.skill20 += 1 * time;
		ent_move (my.skill1, nullvector);
		wait (1);
	}
	remove_bullet();
}

function remove_bullet()
{
	wait (1);
	ent_remove(me);
}

